# Django Contractor

You need additional CSS/JS on your website, but don't want to include it in your Django project? Build it somewhere else, notify contractor via webhook and it will fetch the files from a URL into a versioned media directory. Then you can use them in your website like normal Django media files.
